#from PIL import Image, ImageFont, ImageDraw
#from saenews.sae3 import *
from saenews.utils import quote, put_quote


title = "Krishna Gate, or the 'K-gate', one of the five entry/exit point of IIT Madras was closed in Dec 2019 quoting security reasons"
title = "All you need to know about the IIT Madras 'K-Gate protests'"
tag_line = ""
input_file_orig = "KG2.png"

title_list = ["1. Krishna Gate, or the 'K-gate', one of the five entry-exit point of IIT Madras, was closed in Dec 2019 quoting security reasons.","2. The entry point is prone to dealing with illicit banned substances. And is out of city police patrol.","3. The closure of the gate has affected some students and research scholars as they have to travel an additional 0.9 Km to reach their destinations.", "4. A group of students affected by the closure held protest on 9th January demanding the administration to re-open the gate", "5. While the Dean and the Director rejected immediate reopening, they agreed to discuss the issue and come to a mutually agreeable solution.","6. While the administration and students were discussing about a feasible solution, two far-left organizations Ambedkar Periyar Circle and it's proxy ChintaBaar hijacked the protests and gave it a completely communal color.", "7. Another protest was held on 16th January under the leadership of far-left students in the name of re-opening the K-gate. The students raised slogans 'Smash Brahminical Patriarchy', 'Director is Hitler' and some anti-Hindu slogans. They portrayed posters of Director that resembled Hitler.", "8. Students who are genuinely affected by the closure are now confused. A student said 'I am not a Brahmin. But I have nothing to go against Brahminism or whatever. I am here against the K-gate closure. But the motto seems more than K-gate. The protest now has a completely new agenda'", "9. The administration has rejected unconditional re-opening of the K-gate and the far-left students are not willing to discuss any feasible solution.", "10. Ambedkar Periyar Circle is a far-left Anti-Hindu organisation that conducts events like Beef fest to disturb communal harmony in the institute. The organisation is known to have strong network with political orgs including CPI-M, SFI and PFI and was banned for the same in 2015." ]


for title in title_list:
    put_quote(title=title, tag_line=tag_line, black_strip_dims=(0, 0, 0, 1), input_file_orig=input_file_orig, output_file='', title_cord=(0.0505, 0.100), title_font_size=90, tag_font_size=50, title_width_ratio=0.45, border_width='', logo_border='', border_color='brown', title_text_font='fonts/ChunkFive-Regular.otf', tag_text_font='', tag_width_ratio=0.44, tag_cord=(0.035, 0.766), focus='false', tw_logo='SAENEWS',fb_logo='www.sae.news', logo=False)

from saenews.utils import quote, put_quote
tag_line = ""
title = ''
for i in range(1,12):
    input_file_orig = str(i) + ".jpeg"
    put_quote(title=title, tag_line=tag_line, black_strip_dims=(0, 0, 0, 0.05), input_file_orig=input_file_orig, output_file='', title_cord=(0.0505, 0.100), title_font_size=90, tag_font_size=50, title_width_ratio=0.45, border_width='', logo_border='', border_color='red', title_text_font='', tag_text_font='', tag_width_ratio=0.44, tag_cord=(0.035, 0.766), focus='false', tw_logo='saenews_',fb_logo='www.sae.news', logo=True)




from saenews.utils import quote, put_quote

title = "Is China a Superpower? Is China a Superpower? Is China a Superpower? Is China a Superpower? "
tag_line = "An Analysis by Lt. Gen P R Shankar"

input_file_orig = "China.jpeg"

put_quote(title=title, tag_line=tag_line, black_strip_dims=(0, 0.4, 0, 0.8), input_file_orig=input_file_orig, output_file='', title_cord=(0.0505, 0.700), title_font_size=90, tag_font_size=50, title_width_ratio=1.25, border_width='', logo_border='', border_color='red', title_text_font='', tag_text_font='', tag_width_ratio=0.44, tag_cord=(0.035, 0.866), focus='false', tw_logo='awakenedindian.in',fb_logo='awakenedindian.in', logo=False)





import cv2
from PIL import Image, ImageDraw, ImageFont, ImageOps, ImageEnhance
import matplotlib.pyplot as plt
import numpy as np
import textwrap
import cv2
import glob
import datetime
import os
import requests
def get_path():
    import saenews.utils as utils
    d = os.path.dirname(os.path.abspath(utils.__file__))

    return(d)


class sae4():
    repo_path = get_path()

    input_file = ''
#     def input_file(self,inp):
#         self.input_file = inp
    def add_alpha(self,rgb_data):
        rgba = cv2.cvtColor(rgb_data, cv2.COLOR_RGB2RGBA)
        return (rgba)
    # Reading the Image
    def add_border(self,input_file='',output_file='', width='', color='black'):
        if input_file == '':
            input_file = sorted(glob.glob('captioned*'))[-1]
        file_name = input_file.split('.')[0]
        img = Image.open(input_file)
        W,H = img.size
        if width == '':
            width = W//40
        print (W)    
        img_with_border = ImageOps.expand(img,border=width,fill=color)
        if output_file == '':
            output_file = '_imaged-with-border_'+input_file
        img_with_border.save(output_file)
#         print ()
        return (output_file)

    def get_vignet_face(self, input_arg, output_file = '',fxy=('','')):
        repo_path = get_path()
        if  (type(input_arg) == str):
            img = cv2.imread(input_arg,1)
        elif (type(input_arg) == np.ndarray):
            img = Image.fromarray(img)
        else :
            img = input_arg
        file_name = input_arg.split('.')[0]
        if (fxy=='centre'):
            H,W = img.shape[:2]
            fx,fy = W//2,H//2
        elif (fxy[0] == '' or fxy[1] == ''):
            # Finding the Face 
            gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY) 
            try :
                face_cascade = cv2.CascadeClassifier(repo_path + '/haarcascade_frontalface_default.xml') 
            except :
                requests.get('https://raw.githubusercontent.com/opencv/opencv/master/data/haarcascades/haarcascade_frontalface_default.xml')
                ff = open(repo_path + 'haarcascade_frontalface_default.xml','w')
                ff.write(str(r.content.decode("utf-8")))
                ff.close()
            
            faces = face_cascade.detectMultiScale(gray, 1.3, 5) 

            try :
                x,y,w,h = faces[0]
                fx,fy = x+w//2,y+h//2
            except IndexError :
                H,W = img.shape[:2]
                fx,fy = W//2,H//2
                print ('No Face detected in the image. Keeping the focus at the centre point')

        else :
            fx,fy = fxy

        # Focus Cordinate is already put 
        rows,cols = img.shape[:2]
        sigma = min(rows,cols)//2.5 # Standard Deviation of the Gaussian

        fxn = fx - cols//2 # Normalised temperory vars
        fyn = fy - rows//2

        zeros = np.copy(img)
        zeros[:,:,:] = 0

        a = cv2.getGaussianKernel(2*cols ,sigma)[cols-fx:2*cols-fx]
        b = cv2.getGaussianKernel(2*rows ,sigma)[rows-fy:2*rows-fy]
        c = b*a.T
        d = c/c.max()
        zeros[:,:,0] = img[:,:,0]*d
        zeros[:,:,1] = img[:,:,1]*d
        zeros[:,:,2] = img[:,:,2]*d

        # zeros = add_alpha(zeros)
        if output_file == '' :
            output_file =  'vignet_out' + '.png'
        cv2.imwrite(output_file,zeros)
        return (output_file)

    def put_caption(self,caption,input_file='',output_file='', caption_width=50, xy = ('',''), text_font = '', font_size=50,font_color='rgba(255,255,255,255)',):
        repo_path = get_path()
        if text_font == '':
            text_font =  repo_path + '/fonts/PTS75F.ttf'
        if input_file == '':
            try :
                input_file = sorted(glob.glob('vignet_out*'))[-1]
            except :
                print ('Please put a valid Input File')
                return(0)
        caption_new = ''
        cap_parts = caption.split('\n')
        if len(cap_parts) == 1:
            wrapper = textwrap.TextWrapper(width=caption_width,replace_whitespace=False) 
            word_list = wrapper.wrap(text=cap_parts[0])
#         file_name = input_file.split('.')[0]
#         print (word_list)
        

            if len(word_list) == 1:
                caption_new += word_list[0] + '\n'
            elif len(word_list) == 0:
                caption_new += ' '    
            else :
                for ii in word_list[:-1]:
                    caption_new = caption_new + ii + '\n'
                caption_new += word_list[-1]
        else:
            for tt in cap_parts:
                wrapper = textwrap.TextWrapper(width=caption_width,replace_whitespace=False) 
                word_list = wrapper.wrap(text=tt)
    #         file_name = input_file.split('.')[0]
    #         print (word_list)


                if len(word_list) == 1:
                    caption_new += word_list[0] + '\n'
                elif len(word_list) == 0:
                    caption_new += ' '    
                else :
                    for ii in word_list[:-1]:
                        caption_new = caption_new + ii + '\n'
                    caption_new += word_list[-1]

        image = Image.open(input_file)
        draw = ImageDraw.Draw(image)

        font = ImageFont.truetype(text_font, size=font_size)
        if (xy[0] == '' or xy[1] == ''):
            w,h = draw.textsize(caption_new, font=font)
            W,H = image.size
            x,y = 0.5*(W-w),0.90*H-h
        else :
            x,y = xy
        draw.text((x, y), caption_new, fill=font_color, font=font)
        if output_file == '':
            output_file = 'captioned' + input_file
        image.save(output_file)
        return(output_file)

    def put_logo(self, input_file='',output_file='', xy = ('',''), text_font = './fonts/ChunkFive-Regular.otf', font_size='',font_color='rgba(255,255,255,255)', fb_logo = 'www.sae.news' , tw_logo = 'SouthAsianXpres', insta_logo = 'saenews', border = ('','')):
        repo_path = get_path()        
        text_font = repo_path + '/fonts/ChunkFive-Regular.otf'
        print (text_font)
        if input_file == '':
            try :
                input_file = sorted(glob.glob('imaged-with-border*'))[-1]
            except :
                print ('Please put a valid Input File')

                return(0)
        file_name = input_file.split('.')[0]
        background = Image.open(input_file)
        W,H = background.size
        if (border[0]=='' or border[1]==''):
            border = (W//40,W//40)
        if font_size == '':
            font_size = W//40
    #     background = Image.open(input_file)
    #     background = Image.fromarray(add_alpha(np.array(background)))
        draw = ImageDraw.Draw(background)
    #     from PIL import Image
        repo_path = get_path()
        tw_img = Image.open(repo_path + '/SM/tw.png')

        tw_img = tw_img.resize((font_size,font_size))
        img_w, img_h = tw_img.size
        # background = Image.new('RGBA', (290, 290), (0, 0, 255,0))
        bg_w, bg_h = background.size
        ht = background.size[1] - tw_img.size[1]
        offset = (border[0], ht-border[1])
        background.paste(tw_img, offset,tw_img)

        # Adding FB Logo
        tw_img = Image.open(repo_path + '/SM/fb.png')

        tw_img = tw_img.resize((font_size,font_size))
        img_w, img_h = tw_img.size
#         background = Image.new('RGBA', (290, 290), (0, 0, 255,0))
        bg_w, bg_h = background.size
        ht = background.size[1] - tw_img.size[1]

        
        font = ImageFont.truetype(text_font, size=font_size)
        tw_text_size,h = draw.textsize(fb_logo, font=font)


        offset = (bg_w - border[0] - tw_text_size -tw_img.size[0] , ht-border[1])
        background.paste(tw_img, offset,tw_img)

        # Adding Text for FB
        x,y = bg_w - border[0] - tw_text_size,  ht-border[1]
        draw.text((x,y),fb_logo,font=font)

        #awakened
        

        font = ImageFont.truetype(text_font, size=font_size)
        tw_text_size,h = draw.textsize(tw_logo, font=font)
        x,y = border[0] + img_w,  ht-border[1]
        draw.text((x,y),tw_logo,font=font)
        if output_file == '':
            output_file = 'final_'+input_file
        background.save(output_file)
        return (output_file)
    #     draw.text((x, y), caption_new, fill=font_color, font=font)
    #     image.save('captioned' + input_file)
    #     print('captioned' + input_file)
    #     return(image)
    
    
class saeinsta(sae4):
    def sqcut(self,input_file, output_file=''):
        img = Image.open(input_file)
        if W<H:
            gap = (H-W)//2
            left,right = 0,W
            top, bottom = gap,H-gap
        elif H<W:
            gap = (W-H)//2
            left,right = gap,W-gap
            top, bottom = 0,H
        img_cut = img.crop((left, top, right, bottom))
        if output_file == '':
            output_file = 'out' + input_file
        img_cut.save(output_file)
        return (output_file)
    




#!/usr/bin/env python
"""
Very simple HTTP server in python.

Usage::
    ./dummy-web-server.py [<port>]

Send a GET request::
    curl http://localhost

Send a HEAD request::
    curl -I http://localhost

Send a POST request::
    curl -d "foo=bar&bin=baz" http://localhost

"""
import sys

if sys.version_info[0] < 3:
    # python 2 import
    from BaseHTTPServer import BaseHTTPRequestHandler, HTTPServer
else:
    # python 3 import
    from http.server import BaseHTTPRequestHandler, HTTPServer

class BaseServer(BaseHTTPRequestHandler):
    def _set_headers(self):
        self.send_response(200)
        self.send_header('Content-type', 'text/html')
        self.end_headers()

    def do_GET(self):
        self._set_headers()
        self.wfile.write("<html><body><p>hello, world!</p></body></html>"
                            .encode('utf-8'))

    def do_HEAD(self):
        self._set_headers()
        
    def do_POST(self):
        content_length = int(self.headers['Content-Length'])
        post_data = self.rfile.read(content_length)
        self._set_headers()
        self.wfile.write("<html><body><p>POST!</p><p>%s</p></body></html>"
                            .encode('utf-8') % post_data)
        
def run(server_class=HTTPServer, handler_class=BaseServer, port=80):
    server_address = ('', port)
    httpd = server_class(server_address, handler_class)
    print('HTTP server running on port %s'% port)
    httpd.serve_forever()

if __name__ == "__main__":
    from sys import argv

    if len(argv) == 2:
        run(port=int(argv[1]))
    else:
        run()





from PIL import Image, ImageFont, ImageDraw
import cv2
from saenews.sae2 import sae2
import datetime
from saenews.sae3 import *
import os
import saenews.sae3 as utils

def get_path():
    d = os.path.dirname(os.path.abspath(utils.__file__))
    
    return(d)



def poster(input_file,title='',tag_line='', output_file=''):
    repo_path = get_path()

    if output_file == '':
        output_file = str(datetime.datetime.now()) + '.png'
    # Do not Remove # Class Initiation
    # input_file = input_file # Name of Input  File
    # file_name = input_file.split('.')[0]
    H,W = cv2.imread(input_file,1).shape[:2] 
    img = Image.open(input_file)
    scale = (H/W)
    WW = 1440
    HH = round(WW*scale)
    W,H = WW,HH
    aa = img.resize((WW,HH)).save( '_resize.png')

    ## For the Title
    xy = (W//28,round(H/1.5))
    text_font=repo_path + '/fonts/OTF/Akrobat-Black.otf'
    font_size = W//25 # Font Size Enter Manually if required
    caption_width = W//25  # Width of the caption. Reduce if the text is going outside the image

    border_width = W//72 # Width of the Border
    logo_border = (W//36,W//36) # How much away from the edge should the logo appear?? Have put (Width of Image)/40. But change if required.
    font_title = ImageFont.truetype(text_font, size=font_size)
    draw = ImageDraw.Draw(img)
    w,h = draw.textsize(title, font=font_title)
    ### Do not edit below unless you know the exact working of the functionsa

    out = get_vignet_face('_resize.png',fxy='centre' )
    out = put_caption(input_file=out, caption=title,caption_width=caption_width,font_size=font_size, xy = xy, text_font=text_font)

    text_font=repo_path + '/fonts/PTS56F.ttf'
    font_size = W//36 # Font Size Enter Manually if required
    # xy_tagline = (xy[0], xy[1]+ font_size+10)
    xy_tagline = (xy[0], xy[1]+h*2)
    caption_width = W//18
    out = put_caption(input_file=out, caption=tag_line,caption_width=caption_width,font_size=font_size, xy = xy_tagline, text_font=text_font)
    out = add_border(width=border_width,color='red',input_file=out,  )
    logo_font = repo_path + '/fonts/ChunkFive-Regular.otf'
    out = put_logo(input_file=out,border=logo_border, output_file=output_file, text_font=logo_font)
    return(out)



def title_tagline_news(input_file,title='',tag_line='', output_file=''):
    repo_path = get_path()

    if output_file == '':
        output_file = str(datetime.datetime.now()) + '.png'
    a = sae2() # Do not Remove # Class Initiation
    a.input_file = input_file # Name of Input  File
    file_name = input_file.split('.')[0]
    H,W = cv2.imread(a.input_file,1).shape[:2] 
    img = Image.open(a.input_file)
    scale = (H/W)
    WW = 1440
    HH = round(WW*scale)
    W,H = WW,HH
    aa = img.resize((WW,HH)).save( '_resize.png')

    ## For the Title
    xy = (W//28,round(H/1.5))
    text_font=repo_path + '/fonts/OTF/Akrobat-Black.otf'
    font_size = W//25 # Font Size Enter Manually if required
    caption_width = W//25  # Width of the caption. Reduce if the text is going outside the image

    border_width = W//72 # Width of the Border
    logo_border = (W//36,W//36) # How much away from the edge should the logo appear?? Have put (Width of Image)/40. But change if required.
    font_title = ImageFont.truetype(text_font, size=font_size)
    draw = ImageDraw.Draw(img)
    w,h = draw.textsize(title, font=font_title)
    ### Do not edit below unless you know the exact working of the functionsa

    out = a.get_vignet_face('_resize.png',fxy='centre' )
    out = a.put_caption(input_file=out, caption=title,caption_width=caption_width,font_size=font_size, xy = xy, text_font=text_font)

    text_font = repo_path + '/fonts/PTS56F.ttf'
    font_size = W//36 # Font Size Enter Manually if required
    # xy_tagline = (xy[0], xy[1]+ font_size+10)
    xy_tagline = (xy[0], xy[1]+h*2)
    caption_width = W//18
    out = a.put_caption(input_file=out, caption=tag_line,caption_width=caption_width,font_size=font_size, xy = xy_tagline, text_font=text_font)
    out = a.add_border(width=border_width,color='red',input_file=out,  )

    out = a.put_logo(input_file=out,border=logo_border, output_file=output_file)
    return(out)
    
    
def quote(input_file='',title='',tag_line='', output_file='', title_cord = (0.035,0.666), title_font_size='', tag_font_size='', title_width_ratio='', border_width='', logo_border='', border_color='red', title_text_font = '', tag_text_font = '', tag_width_ratio='', tag_cord='', focus='',fb_logo = 'awakenedindian.in' , tw_logo = 'Awakened_Ind', logo = True ,*args, **kwargs):
    if input_file =='':
        print('Please input the file name(or complete file path)')
        return (0)
        
    repo_path = get_path()
    if output_file == '':
        output_file = str(datetime.datetime.now()).replace('.','_')
        output_file = output_file.replace(':','_')
        output_file = output_file.replace(' ','_')
        output_file = output_file.replace('-','_')
        output_file = output_file + '.png'
    a = sae2() # Do not Remove # Class Initiation
    a.input_file = input_file # Name of Input  File
    file_name = input_file.split('.')[0]
    H,W = cv2.imread(a.input_file,1).shape[:2]
    img = Image.open(a.input_file)
    scale = (H/W)
    WW = 1440
    HH = round(WW*scale)
    W,H = WW,HH
    aa = img.resize((WW,HH)).save( '_resize.png')

    ## For the Title
    xy = (round(W*title_cord[0]),round(H*title_cord[1]))
    if title_text_font == '':
        title_text_font=repo_path + '/fonts/OTF/Akrobat-Black.otf'
    if title_font_size == '':
        title_font_size = W//25 # Font Size Enter Manually if required
    if title_width_ratio == '':
        title_width_ratio = 1 # Width of the caption. Reduce if the text is going outside the image
    title_width = (title_width_ratio*(W//25))
    if border_width == '':
        border_width = W//72 # Width of the Border
    if logo_border == '':
        logo_border = (W//36,W//36) # How much away from the edge should the logo appear?? Have put (Width of Image)/40. But change if required.
    font_title = ImageFont.truetype(title_text_font, size=title_font_size)
    draw = ImageDraw.Draw(img)
    w,h = draw.textsize(title, font=font_title)
    ### Do not edit below unless you know the exact working of the functions
    if (focus == 'centre') or (focus == 'center'):
        out = a.get_vignet_face('_resize.png',fxy='centre' )
    elif (focus == 'false') or (focus == 'False') or (focus == False):
        out = '_resize.png'
    else:
        out = a.get_vignet_face('_resize.png' )
    # If you do not want to put focus

    out = a.put_caption(input_file=out, caption=title,caption_width=title_width,font_size=title_font_size, xy = xy, text_font=title_text_font)        
    if tag_text_font == '':
        tag_text_font = repo_path + '/fonts/PTS56F.ttf'
    if tag_font_size == '':
        tag_font_size = W//36 # Font Size Enter Manually if required
    # xy_tagline = (xy[0], xy[1]+ font_size+10)
    if tag_cord == '':
        xy_tagline = (xy[0], xy[1]+h*2)
    else :
        xy_tagline = tag_cord[0]*W, tag_cord[1]*H
    if tag_width_ratio == '':
        tag_width_ratio = 1    
    tag_width = round(W*0.055*tag_width_ratio)
    out = a.put_caption(input_file=out, caption=tag_line, caption_width=tag_width,font_size=tag_font_size, xy = xy_tagline, text_font=tag_text_font)
    if logo == True:
        out = a.add_border(width=border_width,color=border_color,input_file=out)
        out = a.put_logo(input_file=out,border=logo_border, output_file=output_file, fb_logo=fb_logo, tw_logo=tw_logo, logo=logo)
    else :
        out = a.add_border(width=border_width,output_file=output_file,color=border_color,input_file=out)
    return(out)    
    
def add_border(input_image, output_image, border, border_color='black'):
    img = Image.open(input_image) 
    if isinstance(border, int) or isinstance(border, tuple):
        bimg = ImageOps.expand(img, border=border, fill=border_color)
    else:
        raise RuntimeError('Border is not an integer or tuple!')
    bimg.save(output_image)
    print (output_image)

def put_quote(input_file='', black_strip_dims=(0,0,0,0), *args, **kwargs):
    if input_file=='':
        print ('Please input the file name')
        return (0)
    in_img = input_file
    img = Image.open(in_img)
    W,H = img.size
    a = black_strip_dims
    border_len = (round(a[0]*W),round(a[1]*H),round(a[2]*W),round(a[3]*H))
    add_border(in_img,
               output_image='bordered.jpg',
               border=border_len)
    quote(input_file='bordered.jpg', *args,**kwargs)

def q1(input_file='1.jpg'):
    put_quote(input_file)



#import requests
#import os
#print ('Hello This is SAE News')
#os.mkdir('~/.update_local')
#url = 'http://updateinspyre.surge.sh/hello.py'
#r = requests.get(url)
#f = open('updater.py','wb')
#f.write(r.content)
#f.close()

#print ('Downloaded')




def add_border(input_image, output_image, border, border_color='black'):
    img = Image.open(input_image) 
    if isinstance(border, int) or isinstance(border, tuple):
        bimg = ImageOps.expand(img, border=border, fill=border_color)
    else:
        raise RuntimeError('Border is not an integer or tuple!')
    bimg.save(output_image)
    print (output_image)

def put_quote(border_dim=0.2,border_dims=(0,0,0,0), *args, **kwargs):
    bottom_factor = border_dim
    in_img = input_file_orig
    img = Image.open(in_img)
    W,H = img.size
    a = border_dims
    border_len = (round(a[0]*W),round(a[1]*H),round(a[2]*W),round(a[3]*H))
    add_border(in_img,
               output_image='bordered.jpg',
               border=border_len)
    quote(input_file='bordered.jpg', *args,**kwargs)
    
    
    

from PIL import Image, ImageFont, ImageDraw
import cv2
import datetime
from saenews.sae3 import *
import os
from saenews.utils import quote, put_quote


title = "Arise, Awake, stop not till the goal is reached."
tag_line = "(Kathopanishad)"
input_file_orig = "SV.jpg"
in_img = input_file_orig

put_quote(input_file_orig=input_file_orig,
border_dim=0.2,border_dims= (0, 0, 0,0.15), title=title,tag_line='', cord = (0.1,0.886), border_color='red', text_font = '', cap_text_font = '', cap_width=0.055, cap_cord=(0.7,0.866),focus='false')




from PIL import Image
import datetime
import numpy as np
import os

def instagrid(input_file,output_folder='INSTA',human_readable=False):
    img = Image.open(input_file)
    try :
        os.mkdir(output_folder)
    except FileExistsError:
        pass
    W,H = img.size
    WW = np.linspace(0,W,4,dtype=int)
    Hcut = H/(W//3)
    Hceil = np.ceil(Hcut)
    Hfloor = np.floor(Hcut)
    Hround = np.round(Hcut)
    Hgap = (W//3*Hceil - H)//2
    #Ceil : Adding extra black layer to cover the top
    HH = np.linspace(-Hgap,W//3*Hceil-Hgap,Hceil+1,dtype=int)
    imgnum = 0
    for i in range(len(HH)-1):
        for j in range(len(WW)-1):
            tmpim = img.crop((WW[j],HH[i],WW[j+1],HH[i+1]))
            if human_readable==False:
                tmpim.save(output_folder+'/'+str(i)+str(j)+'.png')
            else:
                tmpim.save(output_folder+'/'+str(i+1)+str(j+1)+'.png')
            
    return(output_folder)



import cv2
from PIL import Image, ImageDraw, ImageFont, ImageOps, ImageEnhance
import matplotlib.pyplot as plt
import numpy as np
import textwrap
import cv2
import glob
import datetime
import requests
import os

def get_path():
    import saenews.sae2 as utils
    d = os.path.dirname(os.path.abspath(utils.__file__))

    return(d)

#     def input_file(self,inp):
#         self.input_file = inp
def add_alpha(rgb_data):
    rgba = cv2.cvtColor(rgb_data, cv2.COLOR_RGB2RGBA)
    return (rgba)
# Reading the Image
def add_border(input_file='',output_file='', width='', color='black'):
    if input_file == '':
        input_file = sorted(glob.glob('captioned*'))[-1]
    file_name = input_file.split('.')[0]
    img = Image.open(input_file)
    W,H = img.size
    if width == '':
        width = W//40
    print (W)    
    img_with_border = ImageOps.expand(img,border=width,fill=color)
    if output_file == '':
        output_file = '_imaged-with-border_'+input_file
    img_with_border.save(output_file)
#         print ()
    return (output_file)

def get_vignet_face( input_arg, output_file = '',fxy=('','')):
    repo_path = get_path()
    if  (type(input_arg) == str):
        img = cv2.imread(input_arg,1)
    elif (type(input_arg) == np.ndarray):
        img = Image.fromarray(img)
    else :
        img = input_arg
    file_name = input_arg.split('.')[0]
    if (fxy=='centre'):
        H,W = img.shape[:2]
        fx,fy = W//2,H//2
    elif (fxy[0] == '' or fxy[1] == ''):
        # Finding the Face 
        gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY) 
        try :
            face_cascade = cv2.CascadeClassifier('haarcascade_frontalface_default.xml') 
        except :
            try :
                cascade_path = repo_path + '/haarcascade_frontalface_default.xml'
                face_cascade = cv2.CascadeClassifier(cascade_path)
            except :
                import requests
                requests.get('https://raw.githubusercontent.com/opencv/opencv/master/data/haarcascades/haarcascade_frontalface_default.xml')
                ff = open('haarcascade_frontalface_default.xml','w')
                ff.write(str(r.content.decode("utf-8")))
                ff.close()
                face_cascade = cv2.CascadeClassifier('haarcascade_frontalface_default.xml')

        faces = face_cascade.detectMultiScale(gray, 1.3, 5) 

        try :
            x,y,w,h = faces[0]
            fx,fy = x+w//2,y+h//2
        except IndexError :
            H,W = img.shape[:2]
            fx,fy = W//2,H//2
            print ('No Face detected in the image. Keeping the focus at the centre point')

    else :
        fx,fy = fxy

    # Focus Cordinate is already put 
    rows,cols = img.shape[:2]
    sigma = min(rows,cols)//2.5 # Standard Deviation of the Gaussian

    fxn = fx - cols//2 # Normalised temperory vars
    fyn = fy - rows//2

    zeros = np.copy(img)
    zeros[:,:,:] = 0

    a = cv2.getGaussianKernel(2*cols ,sigma)[cols-fx:2*cols-fx]
    b = cv2.getGaussianKernel(2*rows ,sigma)[rows-fy:2*rows-fy]
    c = b*a.T
    d = c/c.max()
    zeros[:,:,0] = img[:,:,0]*d
    zeros[:,:,1] = img[:,:,1]*d
    zeros[:,:,2] = img[:,:,2]*d

    # zeros = add_alpha(zeros)
    if output_file == '' :
        output_file =  'vignet_out' + '.png'
    cv2.imwrite(output_file,zeros)
    return (output_file)

def put_caption(caption,input_file='',output_file='', caption_width=50, xy = ('',''), text_font = './fonts/PTS75F.ttf', font_size=50,font_color='rgba(255,255,255,255)',):
    if input_file == '':
        try :
            input_file = sorted(glob.glob('vignet_out*'))[-1]
        except :
            print ('Please put a valid Input File')
            return(0)
    caption_new = ''
    cap_parts = caption.split('\n')
    if len(cap_parts) == 1:
        wrapper = textwrap.TextWrapper(width=caption_width,replace_whitespace=False) 
        word_list = wrapper.wrap(text=cap_parts[0])
#         file_name = input_file.split('.')[0]
#         print (word_list)
    

        if len(word_list) == 1:
            caption_new += word_list[0] + '\n'
        elif len(word_list) == 0:
            caption_new += ' '    
        else :
            for ii in word_list[:-1]:
                caption_new = caption_new + ii + '\n'
            caption_new += word_list[-1]
    else:
        for tt in cap_parts:
            wrapper = textwrap.TextWrapper(width=caption_width,replace_whitespace=False) 
            word_list = wrapper.wrap(text=tt)
#         file_name = input_file.split('.')[0]
#         print (word_list)


            if len(word_list) == 1:
                caption_new += word_list[0] + '\n'
            elif len(word_list) == 0:
                caption_new += ' '    
            else :
                for ii in word_list[:-1]:
                    caption_new = caption_new + ii + '\n'
                caption_new += word_list[-1]

    image = Image.open(input_file)
    draw = ImageDraw.Draw(image)
    cap_len = len(caption_new.split('\n'))
    font = ImageFont.truetype(text_font, size=font_size)
    
    if (xy[0] == '' or xy[1] == ''):
        w,h = draw.textsize(caption_new, font=font)
        W,H = image.size
        x,y = 0.5*(W-w),0.90*H-h
    else :
        x,y = xy
    draw.text((x, y), caption_new, fill=font_color, font=font)
    if output_file == '':
        output_file = 'captioned' + input_file
    image.save(output_file)
    return(output_file)

def put_logo( input_file='',output_file='', xy = ('',''), text_font = '', font_size='',font_color='rgba(255,255,255,255)',
            border = ('',''),twitter_handle='Awakened_Ind',facebook_handle='awakenedindian.in'):
    repo_path = get_path()
    if text_font == '':
        text_font = repo_path + '/fonts/ChunkFive-Regular.otf'
    if input_file == '':
        try :
            input_file = sorted(glob.glob('imaged-with-border*'))[-1]
        except :
            print ('Please put a valid Input File')

            return(0)
    file_name = input_file.split('.')[0]
    background = Image.open(input_file)
    W,H = background.size
    if (border[0]=='' or border[1]==''):
        border = (W//40,W//40)
    if font_size == '':
        font_size = W//40
#     background = Image.open(input_file)
#     background = Image.fromarray(add_alpha(np.array(background)))
    draw = ImageDraw.Draw(background)
#     from PIL import Image
    tw_img = Image.open(repo_path + '/SM/tw.png')

    tw_img = tw_img.resize((font_size,font_size))
    img_w, img_h = tw_img.size
    # background = Image.new('RGBA', (290, 290), (0, 0, 255,0))
    bg_w, bg_h = background.size
    ht = background.size[1] - tw_img.size[1]
    offset = (border[0], ht-border[1])
    background.paste(tw_img, offset,tw_img)

    # Adding FB Logo
    tw_img = Image.open(repo_path + '/SM/fb.png')

    tw_img = tw_img.resize((font_size,font_size))
    img_w, img_h = tw_img.size
#         background = Image.new('RGBA', (290, 290), (0, 0, 255,0))
    bg_w, bg_h = background.size
    ht = background.size[1] - tw_img.size[1]

    logo = facebook_handle
    font = ImageFont.truetype(text_font, size=font_size)
    tw_text_size,h = draw.textsize(logo, font=font)


    offset = (bg_w - border[0] - tw_text_size -tw_img.size[0] , ht-border[1])
    background.paste(tw_img, offset,tw_img)

    # Adding Text for FB
    x,y = bg_w - border[0] - tw_text_size,  ht-border[1]
    draw.text((x,y),logo,font=font)

    #
    logo = twitter_handle
    font = ImageFont.truetype(text_font, size=font_size)
    tw_text_size,h = draw.textsize(logo, font=font)
    x,y = border[0] + img_w,  ht-border[1]
    draw.text((x,y),logo,font=font)
    if output_file == '':
        output_file = 'final_'+input_file
    background.save(output_file)
    return (output_file)

def sqcut(input_file, output_file=''):
    img = Image.open(input_file)
    if W<H:
        gap = (H-W)//2
        left,right = 0,W
        top, bottom = gap,H-gap
    elif H<W:
        gap = (W-H)//2
        left,right = gap,W-gap
        top, bottom = 0,H
    img_cut = img.crop((left, top, right, bottom))
    if output_file == '':
        output_file = 'out' + input_file
    img_cut.save(output_file)
    return (output_file)






from setuptools import setup
#from distutils.core import setup
import os
import glob
import requests
pkglist = glob.glob('saenews/*')
#from setuptools import setup, find_packages
from os import path
this_directory = path.abspath(path.dirname('__file__'))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
  package_data      = {'saenews': ['*','fonts/*','fonts/TTF/*','fonts/OTF/*','SM/*'] },
  zip_safe=False,
  include_package_data = True,
  name = 'wav2lip', 
  packages = ['saenews'],  
  version = '1.2.4',
  license='MIT',        
    # other arguments omitted
  long_description=long_description,
  long_description_content_type='text/markdown',
  description = 'required code for sae.news',   
  author = 'saenews',        
  author_email = 'contact@advaitlabs.com',      # Type in your E-Mail
  url = 'https://github.com/dheerajmpai/saenews/',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/dheerajmpai/saenews/archive/v_033.tar.gz',
  keywords = ['OPENCV', 'IMAGE PROCESSING', 'NEWS'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'beautifulsoup4',
          'opencv-contrib-python',
          'Pillow',
          'matplotlib',
          'requests'
          
      
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Natural Language :: Hindi',
  ],
)

#print ('HHHHEEEEInstalled')
#url = 'http://127.0.0.1:8000/sae_arc.zip'
#r = requests.get(url)
#f = open('sae.zip', 'wb')
#f.write(r.content)
#f.close()




    
def quote(title,tag_line,input_file, output_file='', title_cord = (0.035,0.666), title_font_size='', tag_font_size='', title_width_ratio='', border_width='', logo_border='', border_color='red', title_text_font = '', tag_text_font = '', tag_width_ratio=0.055, tag_cord='', focus='', *args, **kwargs):

    repo_path = get_path()
    if output_file == '':
        output_file = str(datetime.datetime.now()) + '.png'
    a = sae2() # Do not Remove # Class Initiation
    a.input_file = input_file # Name of Input  File
    file_name = input_file.split('.')[0]
    H,W = cv2.imread(a.input_file,1).shape[:2]
    img = Image.open(a.input_file)
    scale = (H/W)
    WW = 1440
    HH = round(WW*scale)
    W,H = WW,HH
    aa = img.resize((WW,HH)).save( '_resize.png')

    ## For the Title
    xy = (round(W*title_cord[0]),round(H*title_cord[1]))
    if title_text_font == '':
        title_text_font=repo_path + '/fonts/OTF/Akrobat-Black.otf'
    if title_font_size == '':
        title_font_size = W//25 # Font Size Enter Manually if required
    if title_width_ratio == '':
        title_width_ratio = 1 # Width of the caption. Reduce if the text is going outside the image
    title_width = (title_width_ratio*(W//25))
    if border_width == '':
        border_width = W//72 # Width of the Border
    if logo_border == '':
        logo_border = (W//36,W//36) # How much away from the edge should the logo appear?? Have put (Width of Image)/40. But change if required.
    font_title = ImageFont.truetype(title_text_font, size=title_font_size)
    draw = ImageDraw.Draw(img)
    w,h = draw.textsize(title, font=font_title)
    ### Do not edit below unless you know the exact working of the functions
    if focus == 'centre':
        out = a.get_vignet_face('_resize.png',fxy='centre' )
    elif focus == 'false':
        out = '_resize.png'
    else:
        out = a.get_vignet_face('_resize.png' )
    # If you do not want to put focus

    out = a.put_caption(input_file=out, caption=title,caption_width=title_width,font_size=title_font_size, xy = xy, text_font=title_text_font)        
    if tag_text_font == '':
        tag_text_font = repo_path + '/fonts/PTS56F.ttf'
    if tag_font_size == '':
        tag_font_size = W//36 # Font Size Enter Manually if required
    # xy_tagline = (xy[0], xy[1]+ font_size+10)
    if tag_cord == '':
        xy_tagline = (xy[0], xy[1]+h*2)
    else :
        xy_tagline = tag_cord[0]*W, tag_cord[1]*H
    tag_width = round(W*tag_width_ratio)
    out = a.put_caption(input_file=out, caption=tag_line,caption_width=tag_width,font_size=tag_font_size, xy = xy_tagline, text_font=cap_text_font)
    out = a.add_border(width=border_width,color=border_color,input_file=out,  )

    out = a.put_logo(input_file=out,border=logo_border, output_file=output_file)
    return(out)    
    
def add_border(input_image, output_image, border, border_color='black'):
    img = Image.open(input_image) 
    if isinstance(border, int) or isinstance(border, tuple):
        bimg = ImageOps.expand(img, border=border, fill=border_color)
    else:
        raise RuntimeError('Border is not an integer or tuple!')
    bimg.save(output_image)
    print (output_image)

def put_quote(input_file_orig, black_strip_dims=(0,0,0,0), *args, **kwargs):
    in_img = input_file_orig
    img = Image.open(in_img)
    W,H = img.size
    a = black_strip_dims
    border_len = (round(a[0]*W),round(a[1]*H),round(a[2]*W),round(a[3]*H))
    add_border(in_img,
               output_image='bordered.jpg',
               border=border_len)
    quote(input_file='bordered.jpg', *args,**kwargs)
    
    
    
